# nbag
A better syntax for computational graphs in python.

"nbag" is an abbreviation of "named-by-assignment graph".

This repo is a proof-of-concept of a way to define computational graphs, like those used in sympy 
and pymc, without having to specify the names of variables twice.
